<a id="mypy-boto3-autoscaling"></a>

# mypy-boto3-autoscaling

[![PyPI - mypy-boto3-autoscaling](https://img.shields.io/pypi/v/mypy-boto3-autoscaling.svg?color=blue)](https://pypi.org/project/mypy-boto3-autoscaling)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-autoscaling.svg?color=blue)](https://pypi.org/project/mypy-boto3-autoscaling)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)
[![PyPI - Downloads](https://img.shields.io/pypi/dw/mypy-boto3-autoscaling?color=blue)](https://pypistats.org/packages/mypy-boto3-autoscaling)

![boto3.typed](https://github.com/vemel/mypy_boto3_builder/raw/master/logo.png)

Type annotations for
[boto3.AutoScaling 1.17.101](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/autoscaling.html#AutoScaling)
service compatible with [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright) and other tools.

Generated by
[mypy-boto3-buider 4.20.0](https://github.com/vemel/mypy_boto3_builder).

More information can be found on
[boto3-stubs](https://pypi.org/project/boto3-stubs/) page and in
[mypy-boto3-autoscaling docs](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_autoscaling/)

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/vemel/mypy_boto3_builder/raw/master/demo.gif)

- [mypy-boto3-autoscaling](#mypy-boto3-autoscaling)
  - [How to install](#how-to-install)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)
    - [Literals](#literals)
    - [Typed dictionaries](#typed-dictionaries)
  - [Versioning](#versioning)
  - [Documentation](#documentation)
  - [Support and contributing](#support-and-contributing)

<a id="how-to-install"></a>

## How to install

Install `boto3-stubs` for `AutoScaling` service.

```bash
python -m pip install boto3-stubs[autoscaling]
```

<a id="usage"></a>

## Usage

<a id="vscode"></a>

### VSCode

- Install
  [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install
  [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `boto-stubs[autoscaling]` in your environment:
  `python -m pip install 'boto3-stubs[autoscaling]'`

Both type checking and auto-complete should work for `AutoScaling` service. No
explicit type annotations required, write your `boto3` code as usual.

<a id="pycharm"></a>

### PyCharm

- Install `boto-stubs[autoscaling]` in your environment:
  `python -m pip install 'boto3-stubs[autoscaling]'`

Both type checking and auto-complete should work for `AutoScaling` service. No
explicit type annotations required, write your `boto3` code as usual.
Auto-complete can be slow on big projects or if you have a lot of installed
`boto3-stubs` submodules.

<a id="other-ides"></a>

### Other IDEs

Not tested, but as long as your IDE support `mypy` or `pyright`, everything
should work.

<a id="mypy"></a>

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `boto-stubs[autoscaling]` in your environment:
  `python -m pip install 'boto3-stubs[autoscaling]'`
- Run `mypy` as usual

Type checking should work for `AutoScaling` service. No explicit type
annotations required, write your `boto3` code as usual.

<a id="pyright"></a>

### pyright

- Install `pyright`: `yarn global add pyright`
- Install `boto-stubs[autoscaling]` in your environment:
  `python -m pip install 'boto3-stubs[autoscaling]'`
- Optionally, you can install `boto3-stubs` to `typings` folder.

Type checking should work for `AutoScaling` service. No explicit type
annotations required, write your `boto3` code as usual.

<a id="explicit-type-annotations"></a>

## Explicit type annotations

<a id="client-annotations"></a>

### Client annotations

`AutoScalingClient` provides annotations for `boto3.client("autoscaling")`.

```python
import boto3

from mypy_boto3_autoscaling import AutoScalingClient

client: AutoScalingClient = boto3.client("autoscaling")

# now client usage is checked by mypy and IDE should provide code auto-complete

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: AutoScalingClient = session.client("autoscaling")
```

<a id="paginators-annotations"></a>

### Paginators annotations

`mypy_boto3_autoscaling.paginator` module contains type annotations for all
paginators.

```python
from mypy_boto3_autoscaling import AutoScalingClient
from mypy_boto3_autoscaling.paginator import (
    DescribeAutoScalingGroupsPaginator,
    DescribeAutoScalingInstancesPaginator,
    DescribeLaunchConfigurationsPaginator,
    DescribeLoadBalancerTargetGroupsPaginator,
    DescribeLoadBalancersPaginator,
    DescribeNotificationConfigurationsPaginator,
    DescribePoliciesPaginator,
    DescribeScalingActivitiesPaginator,
    DescribeScheduledActionsPaginator,
    DescribeTagsPaginator,
)

client: AutoScalingClient = boto3.client("autoscaling")

# Explicit type annotations are optional here
# Type should be correctly discovered by mypy and IDEs
# VSCode requires explicit type annotations
describe_auto_scaling_groups_paginator: DescribeAutoScalingGroupsPaginator = client.get_paginator("describe_auto_scaling_groups")
describe_auto_scaling_instances_paginator: DescribeAutoScalingInstancesPaginator = client.get_paginator("describe_auto_scaling_instances")
describe_launch_configurations_paginator: DescribeLaunchConfigurationsPaginator = client.get_paginator("describe_launch_configurations")
describe_load_balancer_target_groups_paginator: DescribeLoadBalancerTargetGroupsPaginator = client.get_paginator("describe_load_balancer_target_groups")
describe_load_balancers_paginator: DescribeLoadBalancersPaginator = client.get_paginator("describe_load_balancers")
describe_notification_configurations_paginator: DescribeNotificationConfigurationsPaginator = client.get_paginator("describe_notification_configurations")
describe_policies_paginator: DescribePoliciesPaginator = client.get_paginator("describe_policies")
describe_scaling_activities_paginator: DescribeScalingActivitiesPaginator = client.get_paginator("describe_scaling_activities")
describe_scheduled_actions_paginator: DescribeScheduledActionsPaginator = client.get_paginator("describe_scheduled_actions")
describe_tags_paginator: DescribeTagsPaginator = client.get_paginator("describe_tags")
```

<a id="literals"></a>

### Literals

`mypy_boto3_autoscaling.literals` module contains literals extracted from
shapes that can be used in user code for type checking.

```python
from mypy_boto3_autoscaling.literals import (
    DescribeAutoScalingGroupsPaginatorName,
    DescribeAutoScalingInstancesPaginatorName,
    DescribeLaunchConfigurationsPaginatorName,
    DescribeLoadBalancerTargetGroupsPaginatorName,
    DescribeLoadBalancersPaginatorName,
    DescribeNotificationConfigurationsPaginatorName,
    DescribePoliciesPaginatorName,
    DescribeScalingActivitiesPaginatorName,
    DescribeScheduledActionsPaginatorName,
    DescribeTagsPaginatorName,
    InstanceMetadataEndpointStateType,
    InstanceMetadataHttpTokensStateType,
    InstanceRefreshStatusType,
    LifecycleStateType,
    MetricStatisticType,
    MetricTypeType,
    PredefinedLoadMetricTypeType,
    PredefinedMetricPairTypeType,
    PredefinedScalingMetricTypeType,
    PredictiveScalingMaxCapacityBreachBehaviorType,
    PredictiveScalingModeType,
    RefreshStrategyType,
    ScalingActivityStatusCodeType,
    WarmPoolStateType,
    WarmPoolStatusType,
)

def check_value(value: DescribeAutoScalingGroupsPaginatorName) -> bool:
    ...
```

<a id="typed-dictionaries"></a>

### Typed dictionaries

`mypy_boto3_autoscaling.type_defs` module contains structures and shapes
assembled to typed dictionaries for additional type checking.

```python
from mypy_boto3_autoscaling.type_defs import (
    ActivitiesTypeResponseTypeDef,
    ActivityTypeDef,
    ActivityTypeResponseTypeDef,
    AdjustmentTypeTypeDef,
    AlarmTypeDef,
    AttachInstancesQueryTypeDef,
    AttachLoadBalancerTargetGroupsTypeTypeDef,
    AttachLoadBalancersTypeTypeDef,
    AutoScalingGroupNamesTypeTypeDef,
    AutoScalingGroupTypeDef,
    AutoScalingGroupsTypeResponseTypeDef,
    AutoScalingInstanceDetailsTypeDef,
    AutoScalingInstancesTypeResponseTypeDef,
    BatchDeleteScheduledActionAnswerResponseTypeDef,
    BatchDeleteScheduledActionTypeTypeDef,
    BatchPutScheduledUpdateGroupActionAnswerResponseTypeDef,
    BatchPutScheduledUpdateGroupActionTypeTypeDef,
    BlockDeviceMappingTypeDef,
    CancelInstanceRefreshAnswerResponseTypeDef,
    CancelInstanceRefreshTypeTypeDef,
    CapacityForecastTypeDef,
    CompleteLifecycleActionTypeTypeDef,
    CreateAutoScalingGroupTypeTypeDef,
    CreateLaunchConfigurationTypeTypeDef,
    CreateOrUpdateTagsTypeTypeDef,
    CustomizedMetricSpecificationTypeDef,
    DeleteAutoScalingGroupTypeTypeDef,
    DeleteLifecycleHookTypeTypeDef,
    DeleteNotificationConfigurationTypeTypeDef,
    DeletePolicyTypeTypeDef,
    DeleteScheduledActionTypeTypeDef,
    DeleteTagsTypeTypeDef,
    DeleteWarmPoolTypeTypeDef,
    DescribeAccountLimitsAnswerResponseTypeDef,
    DescribeAdjustmentTypesAnswerResponseTypeDef,
    DescribeAutoScalingInstancesTypeTypeDef,
    DescribeAutoScalingNotificationTypesAnswerResponseTypeDef,
    DescribeInstanceRefreshesAnswerResponseTypeDef,
    DescribeInstanceRefreshesTypeTypeDef,
    DescribeLifecycleHookTypesAnswerResponseTypeDef,
    DescribeLifecycleHooksAnswerResponseTypeDef,
    DescribeLifecycleHooksTypeTypeDef,
    DescribeLoadBalancerTargetGroupsRequestTypeDef,
    DescribeLoadBalancerTargetGroupsResponseResponseTypeDef,
    DescribeLoadBalancersRequestTypeDef,
    DescribeLoadBalancersResponseResponseTypeDef,
    DescribeMetricCollectionTypesAnswerResponseTypeDef,
    DescribeNotificationConfigurationsAnswerResponseTypeDef,
    DescribeNotificationConfigurationsTypeTypeDef,
    DescribePoliciesTypeTypeDef,
    DescribeScalingActivitiesTypeTypeDef,
    DescribeScheduledActionsTypeTypeDef,
    DescribeTagsTypeTypeDef,
    DescribeTerminationPolicyTypesAnswerResponseTypeDef,
    DescribeWarmPoolAnswerResponseTypeDef,
    DescribeWarmPoolTypeTypeDef,
    DetachInstancesAnswerResponseTypeDef,
    DetachInstancesQueryTypeDef,
    DetachLoadBalancerTargetGroupsTypeTypeDef,
    DetachLoadBalancersTypeTypeDef,
    DisableMetricsCollectionQueryTypeDef,
    EbsTypeDef,
    EnableMetricsCollectionQueryTypeDef,
    EnabledMetricTypeDef,
    EnterStandbyAnswerResponseTypeDef,
    EnterStandbyQueryTypeDef,
    ExecutePolicyTypeTypeDef,
    ExitStandbyAnswerResponseTypeDef,
    ExitStandbyQueryTypeDef,
    FailedScheduledUpdateGroupActionRequestTypeDef,
    FilterTypeDef,
    GetPredictiveScalingForecastAnswerResponseTypeDef,
    GetPredictiveScalingForecastTypeTypeDef,
    InstanceMetadataOptionsTypeDef,
    InstanceMonitoringTypeDef,
    InstanceRefreshLivePoolProgressTypeDef,
    InstanceRefreshProgressDetailsTypeDef,
    InstanceRefreshTypeDef,
    InstanceRefreshWarmPoolProgressTypeDef,
    InstanceTypeDef,
    InstancesDistributionTypeDef,
    LaunchConfigurationNameTypeTypeDef,
    LaunchConfigurationNamesTypeTypeDef,
    LaunchConfigurationTypeDef,
    LaunchConfigurationsTypeResponseTypeDef,
    LaunchTemplateOverridesTypeDef,
    LaunchTemplateSpecificationTypeDef,
    LaunchTemplateTypeDef,
    LifecycleHookSpecificationTypeDef,
    LifecycleHookTypeDef,
    LoadBalancerStateTypeDef,
    LoadBalancerTargetGroupStateTypeDef,
    LoadForecastTypeDef,
    MetricCollectionTypeTypeDef,
    MetricDimensionTypeDef,
    MetricGranularityTypeTypeDef,
    MixedInstancesPolicyTypeDef,
    NotificationConfigurationTypeDef,
    PaginatorConfigTypeDef,
    PoliciesTypeResponseTypeDef,
    PolicyARNTypeResponseTypeDef,
    PredefinedMetricSpecificationTypeDef,
    PredictiveScalingConfigurationTypeDef,
    PredictiveScalingMetricSpecificationTypeDef,
    PredictiveScalingPredefinedLoadMetricTypeDef,
    PredictiveScalingPredefinedMetricPairTypeDef,
    PredictiveScalingPredefinedScalingMetricTypeDef,
    ProcessTypeTypeDef,
    ProcessesTypeResponseTypeDef,
    PutLifecycleHookTypeTypeDef,
    PutNotificationConfigurationTypeTypeDef,
    PutScalingPolicyTypeTypeDef,
    PutScheduledUpdateGroupActionTypeTypeDef,
    PutWarmPoolTypeTypeDef,
    RecordLifecycleActionHeartbeatTypeTypeDef,
    RefreshPreferencesTypeDef,
    ResponseMetadataTypeDef,
    ScalingPolicyTypeDef,
    ScalingProcessQueryTypeDef,
    ScheduledActionsTypeResponseTypeDef,
    ScheduledUpdateGroupActionRequestTypeDef,
    ScheduledUpdateGroupActionTypeDef,
    SetDesiredCapacityTypeTypeDef,
    SetInstanceHealthQueryTypeDef,
    SetInstanceProtectionQueryTypeDef,
    StartInstanceRefreshAnswerResponseTypeDef,
    StartInstanceRefreshTypeTypeDef,
    StepAdjustmentTypeDef,
    SuspendedProcessTypeDef,
    TagDescriptionTypeDef,
    TagTypeDef,
    TagsTypeResponseTypeDef,
    TargetTrackingConfigurationTypeDef,
    TerminateInstanceInAutoScalingGroupTypeTypeDef,
    UpdateAutoScalingGroupTypeTypeDef,
    WarmPoolConfigurationTypeDef,
)

def get_structure() -> ActivitiesTypeResponseTypeDef:
    return {
      ...
    }
```

<a id="versioning"></a>

## Versioning

`mypy-boto3-autoscaling` version is the same as related `boto3` version and
follows [PEP 440](https://www.python.org/dev/peps/pep-0440/) format.

<a id="documentation"></a>

## Documentation

All type annotations can be found in
[mypy-boto3-autoscaling docs](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_autoscaling/)

<a id="support-and-contributing"></a>

## Support and contributing

This package is auto-generated. Please reports any bugs or request new features
in [mypy-boto3-builder](https://github.com/vemel/mypy_boto3_builder/issues/)
repository.
